@@ -13,7 +13,10 @@
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
 # Copyright (c) 2018 Daniel Colascione <dancol@dancol.org>
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
+# Copyright (c) 2021 pre-commit-ci[bot] <bot@noreply.github.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 David Liu <david@cs.toronto.edu>
 # Copyright (c) 2021 doranid <ddandd@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 Andrew Haigh <hello@nelf.in>
@@ -27,19 +30,25 @@ inference utils.
 
 import collections
 
-from astroid import context as contextmod
-from astroid import decorators, util
+from astroid import decorators
 from astroid.const import PY310_PLUS
+from astroid.context import (
+    CallContext,
+    InferenceContext,
+    bind_context_to_node,
+    copy_context,
+)
 from astroid.exceptions import (
     AstroidTypeError,
     AttributeInferenceError,
     InferenceError,
     NameInferenceError,
 )
+from astroid.util import Uninferable, lazy_descriptor, lazy_import
 
-objectmodel = util.lazy_import("interpreter.objectmodel")
-helpers = util.lazy_import("helpers")
-manager = util.lazy_import("manager")
+objectmodel = lazy_import("interpreter.objectmodel")
+helpers = lazy_import("helpers")
+manager = lazy_import("manager")
 
 
 # TODO: check if needs special treatment
@@ -78,7 +87,7 @@ def _is_property(meth, context=None):
     if PROPERTIES.intersection(decoratornames):
         return True
     stripped = {
-        name.split(".")[-1] for name in decoratornames if name is not util.Uninferable
+        name.split(".")[-1] for name in decoratornames if name is not Uninferable
     }
     if any(name in stripped for name in POSSIBLE_PROPERTIES):
         return True
@@ -88,7 +97,7 @@ def _is_property(meth, context=None):
         return False
     for decorator in meth.decorators.nodes or ():
         inferred = helpers.safe_infer(decorator, context=context)
-        if inferred is None or inferred is util.Uninferable:
+        if inferred is None or inferred is Uninferable:
             continue
         if inferred.__class__.__name__ == "ClassDef":
             for base_class in inferred.bases:
@@ -135,10 +144,10 @@ def _infer_stmts(stmts, context, frame=None):
         context = context.clone()
     else:
         name = None
-        context = contextmod.InferenceContext()
+        context = InferenceContext()
 
     for stmt in stmts:
-        if stmt is util.Uninferable:
+        if stmt is Uninferable:
             yield stmt
             inferred = True
             continue
@@ -150,7 +159,7 @@ def _infer_stmts(stmts, context, frame=None):
         except NameInferenceError:
             continue
         except InferenceError:
-            yield util.Uninferable
+            yield Uninferable
             inferred = True
     if not inferred:
         raise InferenceError(
@@ -167,10 +176,11 @@ def _infer_method_result_truth(instance, method_name, context):
     meth = next(instance.igetattr(method_name, context=context), None)
     if meth and hasattr(meth, "infer_call_result"):
         if not meth.callable():
-            return util.Uninferable
+            return Uninferable
         try:
+            context.callcontext = CallContext(args=[], callee=meth)
             for value in meth.infer_call_result(instance, context=context):
-                if value is util.Uninferable:
+                if value is Uninferable:
                     return value
                 try:
                     inferred = next(value.infer(context=context))
@@ -179,7 +189,7 @@ def _infer_method_result_truth(instance, method_name, context):
                 return inferred.bool_value()
         except InferenceError:
             pass
-    return util.Uninferable
+    return Uninferable
 
 
 class BaseInstance(Proxy):
@@ -219,7 +229,7 @@ class BaseInstance(Proxy):
     def igetattr(self, name, context=None):
         """inferred getattr"""
         if not context:
-            context = contextmod.InferenceContext()
+            context = InferenceContext()
         try:
             context.lookupname = name
             # avoid recursively inferring the same attr on the same class
@@ -265,10 +275,10 @@ class BaseInstance(Proxy):
 
     def infer_call_result(self, caller, context=None):
         """infer what a class instance is returning when called"""
-        context = contextmod.bind_context_to_node(context, self)
+        context = bind_context_to_node(context, self)
         inferred = False
         for node in self._proxied.igetattr("__call__", context):
-            if node is util.Uninferable or not node.callable():
+            if node is Uninferable or not node.callable():
                 continue
             for res in node.infer_call_result(caller, context):
                 inferred = True
@@ -281,7 +291,7 @@ class Instance(BaseInstance):
     """A special node representing a class instance."""
 
     # pylint: disable=unnecessary-lambda
-    special_attributes = util.lazy_descriptor(lambda: objectmodel.InstanceModel())
+    special_attributes = lazy_descriptor(lambda: objectmodel.InstanceModel())
 
     def __repr__(self):
         return "<Instance of {}.{} at 0x{}>".format(
@@ -317,8 +327,7 @@ class Instance(BaseInstance):
              nonzero. If a class defines neither __len__() nor __bool__(),
              all its instances are considered true.
         """
-        context = context or contextmod.InferenceContext()
-        context.callcontext = contextmod.CallContext(args=[])
+        context = context or InferenceContext()
         context.boundnode = self
 
         try:
@@ -333,12 +342,12 @@ class Instance(BaseInstance):
 
     def getitem(self, index, context=None):
         # TODO: Rewrap index to Const for this case
-        new_context = contextmod.bind_context_to_node(context, self)
+        new_context = bind_context_to_node(context, self)
         if not context:
             context = new_context
-        # Create a new CallContext for providing index as an argument.
-        new_context.callcontext = contextmod.CallContext(args=[index])
         method = next(self.igetattr("__getitem__", context=context), None)
+        # Create a new CallContext for providing index as an argument.
+        new_context.callcontext = CallContext(args=[index], callee=method)
         if not isinstance(method, BoundMethod):
             raise InferenceError(
                 "Could not find __getitem__ for {node!r}.", node=self, context=context
@@ -356,7 +365,7 @@ class UnboundMethod(Proxy):
     """a special node representing a method not bound to an instance"""
 
     # pylint: disable=unnecessary-lambda
-    special_attributes = util.lazy_descriptor(lambda: objectmodel.UnboundMethodModel())
+    special_attributes = lazy_descriptor(lambda: objectmodel.UnboundMethodModel())
 
     def __repr__(self):
         frame = self._proxied.parent.frame()
@@ -402,7 +411,7 @@ class UnboundMethod(Proxy):
                 infer = caller.args[0].infer(context=node_context)
             else:
                 infer = []
-            return (Instance(x) if x is not util.Uninferable else x for x in infer)
+            return (Instance(x) if x is not Uninferable else x for x in infer)
         return self._proxied.infer_call_result(caller, context)
 
     def bool_value(self, context=None):
@@ -413,10 +422,10 @@ class BoundMethod(UnboundMethod):
     """a special node representing a method bound to an instance"""
 
     # pylint: disable=unnecessary-lambda
-    special_attributes = util.lazy_descriptor(lambda: objectmodel.BoundMethodModel())
+    special_attributes = lazy_descriptor(lambda: objectmodel.BoundMethodModel())
 
     def __init__(self, proxy, bound):
-        UnboundMethod.__init__(self, proxy)
+        super().__init__(proxy)
         self.bound = bound
 
     def implicit_parameters(self):
@@ -436,7 +445,7 @@ class BoundMethod(UnboundMethod):
         needs to be a tuple of classes
         """
         # pylint: disable=import-outside-toplevel; circular import
-        from astroid.nodes import node_classes
+        from astroid.nodes import Pass
 
         # Verify the metaclass
         try:
@@ -507,7 +516,7 @@ class BoundMethod(UnboundMethod):
             col_offset=caller.col_offset,
             parent=caller,
         )
-        empty = node_classes.Pass()
+        empty = Pass()
         cls.postinit(
             bases=bases.elts,
             body=[empty],
@@ -520,7 +529,7 @@ class BoundMethod(UnboundMethod):
         return cls
 
     def infer_call_result(self, caller, context=None):
-        context = contextmod.bind_context_to_node(context, self.bound)
+        context = bind_context_to_node(context, self.bound)
         if (
             self.bound.__class__.__name__ == "ClassDef"
             and self.bound.name == "type"
@@ -544,12 +553,12 @@ class Generator(BaseInstance):
     Proxied class is set once for all in raw_building.
     """
 
-    special_attributes = util.lazy_descriptor(objectmodel.GeneratorModel)
+    special_attributes = lazy_descriptor(objectmodel.GeneratorModel)
 
     def __init__(self, parent=None, generator_initial_context=None):
         super().__init__()
         self.parent = parent
-        self._call_context = contextmod.copy_context(generator_initial_context)
+        self._call_context = copy_context(generator_initial_context)
 
     @decorators.cached
     def infer_yield_types(self):
@@ -568,12 +577,10 @@ class Generator(BaseInstance):
         return True
 
     def __repr__(self):
-        return "<Generator({}) l.{} at 0x{}>".format(
-            self._proxied.name, self.lineno, id(self)
-        )
+        return f"<Generator({self._proxied.name}) l.{self.lineno} at 0x{id(self)}>"
 
     def __str__(self):
-        return "Generator(%s)" % self._proxied.name
+        return f"Generator({self._proxied.name})"
 
 
 class AsyncGenerator(Generator):
@@ -586,9 +593,7 @@ class AsyncGenerator(Generator):
         return "AsyncGenerator"
 
     def __repr__(self):
-        return "<AsyncGenerator({}) l.{} at 0x{}>".format(
-            self._proxied.name, self.lineno, id(self)
-        )
+        return f"<AsyncGenerator({self._proxied.name}) l.{self.lineno} at 0x{id(self)}>"
 
     def __str__(self):
-        return "AsyncGenerator(%s)" % self._proxied.name
+        return f"AsyncGenerator({self._proxied.name})"
