@@ -11,6 +11,7 @@
 # Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 David Gilman <davidgilman1@gmail.com>
 # Copyright (c) 2020 Ram Rachum <ram@rachum.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 Nick Drozd <nicholasdrozd@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
@@ -155,7 +156,7 @@ def _builtin_filter_predicate(node, builtin_name):
         and isinstance(node.parent, nodes.Assign)
         and len(node.parent.targets) == 1
         and isinstance(node.parent.targets[0], nodes.AssignName)
-        and node.parent.targets[0].name in ("Pattern", "Match")
+        and node.parent.targets[0].name in {"Pattern", "Match"}
     ):
         # Handle re.Pattern and re.Match in brain_re
         # Match these patterns from stdlib/re.py
@@ -668,9 +669,7 @@ def infer_issubclass(callnode, context=None):
         raise UseInferenceDefault("TypeError: issubclass() takes no keyword arguments")
     if len(call.positional_arguments) != 2:
         raise UseInferenceDefault(
-            "Expected two arguments, got {count}".format(
-                count=len(call.positional_arguments)
-            )
+            f"Expected two arguments, got {len(call.positional_arguments)}"
         )
     # The left hand argument is the obj to be checked
     obj_node, class_or_tuple_node = call.positional_arguments
@@ -715,9 +714,7 @@ def infer_isinstance(callnode, context=None):
         raise UseInferenceDefault("TypeError: isinstance() takes no keyword arguments")
     if len(call.positional_arguments) != 2:
         raise UseInferenceDefault(
-            "Expected two arguments, got {count}".format(
-                count=len(call.positional_arguments)
-            )
+            f"Expected two arguments, got {len(call.positional_arguments)}"
         )
     # The left hand argument is the obj to be checked
     obj_node, class_or_tuple_node = call.positional_arguments
