@@ -2,16 +2,26 @@
 # For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
 """
 Astroid hook for the dataclasses library
+
+Support both built-in dataclasses and pydantic.dataclasses. References:
+- https://docs.python.org/3/library/dataclasses.html
+- https://pydantic-docs.helpmanual.io/usage/dataclasses/
 """
-from typing import Generator, List, Optional, Tuple
+from typing import FrozenSet, Generator, List, Optional, Tuple
 
 from astroid import context, inference_tip
 from astroid.builder import parse
 from astroid.const import PY37_PLUS, PY39_PLUS
-from astroid.exceptions import AstroidSyntaxError, InferenceError, MroError
+from astroid.exceptions import (
+    AstroidSyntaxError,
+    InferenceError,
+    MroError,
+    UseInferenceDefault,
+)
 from astroid.manager import AstroidManager
 from astroid.nodes.node_classes import (
     AnnAssign,
+    Assign,
     AssignName,
     Attribute,
     Call,
@@ -25,7 +35,7 @@ from astroid.util import Uninferable
 
 DATACLASSES_DECORATORS = frozenset(("dataclass",))
 FIELD_NAME = "field"
-DATACLASS_MODULE = "dataclasses"
+DATACLASS_MODULES = frozenset(("dataclasses", "pydantic.dataclasses"))
 DEFAULT_FACTORY = "_HAS_DEFAULT_FACTORY"  # based on typing.py
 
 
@@ -34,25 +44,10 @@ def is_decorated_with_dataclass(node, decorator_names=DATACLASSES_DECORATORS):
     if not isinstance(node, ClassDef) or not node.decorators:
         return False
 
-    for decorator_attribute in node.decorators.nodes:
-        if isinstance(decorator_attribute, Call):  # decorator with arguments
-            decorator_attribute = decorator_attribute.func
-
-        try:
-            inferred = next(decorator_attribute.infer())
-        except (InferenceError, StopIteration):
-            continue
-
-        if not isinstance(inferred, FunctionDef):
-            continue
-
-        if (
-            inferred.name in decorator_names
-            and inferred.root().name == DATACLASS_MODULE
-        ):
-            return True
-
-    return False
+    return any(
+        _looks_like_dataclass_decorator(decorator_attribute, decorator_names)
+        for decorator_attribute in node.decorators.nodes
+    )
 
 
 def dataclass_transform(node: ClassDef) -> None:
@@ -151,20 +146,7 @@ def _check_generate_dataclass_init(node: ClassDef) -> bool:
         if not isinstance(decorator_attribute, Call):
             continue
 
-        func = decorator_attribute.func
-
-        try:
-            inferred = next(func.infer())
-        except (InferenceError, StopIteration):
-            continue
-
-        if not isinstance(inferred, FunctionDef):
-            continue
-
-        if (
-            inferred.name in DATACLASSES_DECORATORS
-            and inferred.root().name == DATACLASS_MODULE
-        ):
+        if _looks_like_dataclass_decorator(decorator_attribute):
             found = decorator_attribute
 
     if found is None:
@@ -255,9 +237,11 @@ def infer_dataclass_attribute(
 
 
 def infer_dataclass_field_call(
-    node: AssignName, ctx: context.InferenceContext = None
+    node: Call, ctx: Optional[context.InferenceContext] = None
 ) -> Generator:
     """Inference tip for dataclass field calls."""
+    if not isinstance(node.parent, (AnnAssign, Assign)):
+        raise UseInferenceDefault
     field_call = node.parent.value
     default_type, default = _get_field_default(field_call)
     if not default_type:
@@ -270,6 +254,36 @@ def infer_dataclass_field_call(
         yield from new_call.infer(context=ctx)
 
 
+def _looks_like_dataclass_decorator(
+    node: NodeNG, decorator_names: FrozenSet[str] = DATACLASSES_DECORATORS
+) -> bool:
+    """Return True if node looks like a dataclass decorator.
+
+    Uses inference to lookup the value of the node, and if that fails,
+    matches against specific names.
+    """
+    if isinstance(node, Call):  # decorator with arguments
+        node = node.func
+    try:
+        inferred = next(node.infer())
+    except (InferenceError, StopIteration):
+        inferred = Uninferable
+
+    if inferred is Uninferable:
+        if isinstance(node, Name):
+            return node.name in decorator_names
+        if isinstance(node, Attribute):
+            return node.attrname in decorator_names
+
+        return False
+
+    return (
+        isinstance(inferred, FunctionDef)
+        and inferred.name in decorator_names
+        and inferred.root().name in DATACLASS_MODULES
+    )
+
+
 def _looks_like_dataclass_attribute(node: Unknown) -> bool:
     """Return True if node was dynamically generated as the child of an AnnAssign
     statement.
@@ -307,7 +321,7 @@ def _looks_like_dataclass_field_call(node: Call, check_scope: bool = True) -> bo
     if not isinstance(inferred, FunctionDef):
         return False
 
-    return inferred.name == FIELD_NAME and inferred.root().name == DATACLASS_MODULE
+    return inferred.name == FIELD_NAME and inferred.root().name in DATACLASS_MODULES
 
 
 def _get_field_default(field_call: Call) -> Tuple[str, Optional[NodeNG]]:
@@ -397,10 +411,11 @@ def _infer_instance_from_annotation(
         yield Uninferable
     if not isinstance(klass, ClassDef):
         yield Uninferable
-    elif klass.root().name in (
+    elif klass.root().name in {
         "typing",
+        "_collections_abc",
         "",
-    ):  # "" because of synthetic nodes in brain_typing.py
+    }:  # "" because of synthetic nodes in brain_typing.py
         if klass.name in _INFERABLE_TYPING_TYPES:
             yield klass.instantiate_class()
         else:
