@@ -1,5 +1,5 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
+# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
 
 # Copyright (c) 2017-2018 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
@@ -7,30 +7,33 @@
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Tim Martin <tim@asymptotic.co.uk>
 # Copyright (c) 2021 hippo91 <guillaume.peillex@gmail.com>
 
 """Astroid hooks for typing.py support."""
 import typing
 from functools import partial
 
-from astroid import context, extract_node, inference_tip, node_classes
-from astroid.const import PY37_PLUS, PY39_PLUS
+from astroid import context, extract_node, inference_tip
+from astroid.const import PY37_PLUS, PY38_PLUS, PY39_PLUS
 from astroid.exceptions import (
     AttributeInferenceError,
     InferenceError,
     UseInferenceDefault,
 )
 from astroid.manager import AstroidManager
-from astroid.node_classes import (
+from astroid.nodes.node_classes import (
     Assign,
     AssignName,
     Attribute,
     Call,
     Const,
     Name,
+    NodeNG,
     Subscript,
+    Tuple,
 )
-from astroid.scoped_nodes import ClassDef, FunctionDef
+from astroid.nodes.scoped_nodes import ClassDef, FunctionDef
 from astroid.util import Uninferable
 
 TYPING_NAMEDTUPLE_BASENAMES = {"NamedTuple", "typing.NamedTuple"}
@@ -115,7 +118,7 @@ def infer_typing_typevar_or_newtype(node, context_itton=None):
     """Infer a typing.TypeVar(...) or typing.NewType(...) call"""
     try:
         func = next(node.func.infer(context=context_itton))
-    except InferenceError as exc:
+    except (InferenceError, StopIteration) as exc:
         raise UseInferenceDefault from exc
 
     if func.qname() not in TYPING_TYPEVARS_QUALIFIED:
@@ -145,7 +148,7 @@ def infer_typing_attr(
     """Infer a typing.X[...] subscript"""
     try:
         value = next(node.value.infer())
-    except InferenceError as exc:
+    except (InferenceError, StopIteration) as exc:
         raise UseInferenceDefault from exc
 
     if (
@@ -161,7 +164,7 @@ def infer_typing_attr(
         PY37_PLUS
         and isinstance(value, ClassDef)
         and value.qname()
-        in ("typing.Generic", "typing.Annotated", "typing_extensions.Annotated")
+        in {"typing.Generic", "typing.Annotated", "typing_extensions.Annotated"}
     ):
         # With PY37+ typing.Generic and typing.Annotated (PY39) are subscriptable
         # through __class_getitem__. Since astroid can't easily
@@ -185,10 +188,18 @@ def infer_typing_attr(
 
 
 def _looks_like_typedDict(  # pylint: disable=invalid-name
-    node: FunctionDef,
+    node: typing.Union[FunctionDef, ClassDef],
 ) -> bool:
     """Check if node is TypedDict FunctionDef."""
-    return isinstance(node, FunctionDef) and node.name == "TypedDict"
+    return node.qname() in {"typing.TypedDict", "typing_extensions.TypedDict"}
+
+
+def infer_old_typedDict(  # pylint: disable=invalid-name
+    node: ClassDef, ctx: context.InferenceContext = None
+) -> typing.Iterator[ClassDef]:
+    func_to_add = extract_node("dict")
+    node.locals["__call__"] = [func_to_add]
+    return iter([node])
 
 
 def infer_typedDict(  # pylint: disable=invalid-name
@@ -202,6 +213,8 @@ def infer_typedDict(  # pylint: disable=invalid-name
         parent=node.parent,
     )
     class_def.postinit(bases=[extract_node("dict")], body=[], decorators=None)
+    func_to_add = extract_node("dict")
+    class_def.locals["__call__"] = [func_to_add]
     return iter([class_def])
 
 
@@ -215,14 +228,11 @@ def _looks_like_typing_alias(node: Call) -> bool:
     :param node: call node
     """
     return (
-        isinstance(node, Call)
-        and isinstance(node.func, Name)
+        isinstance(node.func, Name)
         and node.func.name == "_alias"
         and (
             # _alias function works also for builtins object such as list and dict
-            isinstance(node.args[0], Attribute)
-            or isinstance(node.args[0], Name)
-            and node.args[0].name != "type"
+            isinstance(node.args[0], (Attribute, Name))
         )
     )
 
@@ -268,8 +278,12 @@ def infer_typing_alias(
         or not len(node.parent.targets) == 1
         or not isinstance(node.parent.targets[0], AssignName)
     ):
-        return None
-    res = next(node.args[0].infer(context=ctx))
+        raise UseInferenceDefault
+    try:
+        res = next(node.args[0].infer(context=ctx))
+    except StopIteration as e:
+        raise InferenceError(node=node.args[0], context=context) from e
+
     assign_name = node.parent.targets[0]
 
     class_def = ClassDef(
@@ -286,9 +300,7 @@ def infer_typing_alias(
     maybe_type_var = node.args[1]
     if (
         not PY39_PLUS
-        and not (
-            isinstance(maybe_type_var, node_classes.Tuple) and not maybe_type_var.elts
-        )
+        and not (isinstance(maybe_type_var, Tuple) and not maybe_type_var.elts)
         or PY39_PLUS
         and isinstance(maybe_type_var, Const)
         and maybe_type_var.value > 0
@@ -304,38 +316,58 @@ def infer_typing_alias(
     return iter([class_def])
 
 
-def _looks_like_tuple_alias(node: Call) -> bool:
-    """Return True if call is for Tuple alias.
+def _looks_like_special_alias(node: Call) -> bool:
+    """Return True if call is for Tuple or Callable alias.
 
     In PY37 and PY38 the call is to '_VariadicGenericAlias' with 'tuple' as
     first argument. In PY39+ it is replaced by a call to '_TupleType'.
 
     PY37: Tuple = _VariadicGenericAlias(tuple, (), inst=False, special=True)
     PY39: Tuple = _TupleType(tuple, -1, inst=False, name='Tuple')
+
+
+    PY37: Callable = _VariadicGenericAlias(collections.abc.Callable, (), special=True)
+    PY39: Callable = _CallableType(collections.abc.Callable, 2)
     """
-    return (
-        isinstance(node, Call)
-        and isinstance(node.func, Name)
+    return isinstance(node.func, Name) and (
+        not PY39_PLUS
+        and node.func.name == "_VariadicGenericAlias"
         and (
-            not PY39_PLUS
-            and node.func.name == "_VariadicGenericAlias"
-            and isinstance(node.args[0], Name)
+            isinstance(node.args[0], Name)
             and node.args[0].name == "tuple"
-            or PY39_PLUS
-            and node.func.name == "_TupleType"
+            or isinstance(node.args[0], Attribute)
+            and node.args[0].as_string() == "collections.abc.Callable"
+        )
+        or PY39_PLUS
+        and (
+            node.func.name == "_TupleType"
             and isinstance(node.args[0], Name)
             and node.args[0].name == "tuple"
+            or node.func.name == "_CallableType"
+            and isinstance(node.args[0], Attribute)
+            and node.args[0].as_string() == "collections.abc.Callable"
         )
     )
 
 
-def infer_tuple_alias(
+def infer_special_alias(
     node: Call, ctx: context.InferenceContext = None
 ) -> typing.Iterator[ClassDef]:
     """Infer call to tuple alias as new subscriptable class typing.Tuple."""
-    res = next(node.args[0].infer(context=ctx))
+    if not (
+        isinstance(node.parent, Assign)
+        and len(node.parent.targets) == 1
+        and isinstance(node.parent.targets[0], AssignName)
+    ):
+        raise UseInferenceDefault
+    try:
+        res = next(node.args[0].infer(context=ctx))
+    except StopIteration as e:
+        raise InferenceError(node=node.args[0], context=context) from e
+
+    assign_name = node.parent.targets[0]
     class_def = ClassDef(
-        name="Tuple",
+        name=assign_name.name,
         parent=node.parent,
     )
     class_def.postinit(bases=[res], body=[], decorators=None)
@@ -344,6 +376,36 @@ def infer_tuple_alias(
     return iter([class_def])
 
 
+def _looks_like_typing_cast(node: Call) -> bool:
+    return isinstance(node, Call) and (
+        isinstance(node.func, Name)
+        and node.func.name == "cast"
+        or isinstance(node.func, Attribute)
+        and node.func.attrname == "cast"
+    )
+
+
+def infer_typing_cast(
+    node: Call, ctx: context.InferenceContext = None
+) -> typing.Iterator[NodeNG]:
+    """Infer call to cast() returning same type as casted-from var"""
+    if not isinstance(node.func, (Name, Attribute)):
+        raise UseInferenceDefault
+
+    try:
+        func = next(node.func.infer(context=ctx))
+    except InferenceError as exc:
+        raise UseInferenceDefault from exc
+    if (
+        not isinstance(func, FunctionDef)
+        or func.qname() != "typing.cast"
+        or len(node.args) != 2
+    ):
+        raise UseInferenceDefault
+
+    return node.args[1].infer(context=ctx)
+
+
 AstroidManager().register_transform(
     Call,
     inference_tip(infer_typing_typevar_or_newtype),
@@ -352,16 +414,23 @@ AstroidManager().register_transform(
 AstroidManager().register_transform(
     Subscript, inference_tip(infer_typing_attr), _looks_like_typing_subscript
 )
+AstroidManager().register_transform(
+    Call, inference_tip(infer_typing_cast), _looks_like_typing_cast
+)
 
 if PY39_PLUS:
     AstroidManager().register_transform(
         FunctionDef, inference_tip(infer_typedDict), _looks_like_typedDict
     )
+elif PY38_PLUS:
+    AstroidManager().register_transform(
+        ClassDef, inference_tip(infer_old_typedDict), _looks_like_typedDict
+    )
 
 if PY37_PLUS:
     AstroidManager().register_transform(
         Call, inference_tip(infer_typing_alias), _looks_like_typing_alias
     )
     AstroidManager().register_transform(
-        Call, inference_tip(infer_tuple_alias), _looks_like_tuple_alias
+        Call, inference_tip(infer_special_alias), _looks_like_special_alias
     )
