@@ -9,6 +9,7 @@
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
 # Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Ram Rachum <ram@rachum.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
@@ -18,6 +19,10 @@
 """ A few useful function/method decorators."""
 
 import functools
+import inspect
+import sys
+import warnings
+from typing import Callable, TypeVar
 
 import wrapt
 
@@ -25,6 +30,14 @@ from astroid import util
 from astroid.context import InferenceContext
 from astroid.exceptions import InferenceError
 
+if sys.version_info >= (3, 10):
+    from typing import ParamSpec
+else:
+    from typing_extensions import ParamSpec
+
+R = TypeVar("R")
+P = ParamSpec("P")
+
 
 @wrapt.decorator
 def cached(func, instance, args, kwargs):
@@ -60,7 +73,7 @@ class cachedproperty:
         try:
             wrapped.__name__
         except AttributeError as exc:
-            raise TypeError("%s must have a __name__ attribute" % wrapped) from exc
+            raise TypeError(f"{wrapped} must have a __name__ attribute") from exc
         self.wrapped = wrapped
 
     @property
@@ -137,3 +150,60 @@ def raise_if_nothing_inferred(func, instance, args, kwargs):
         ) from error
 
     yield from generator
+
+
+def deprecate_default_argument_values(
+    astroid_version: str = "3.0", **arguments: str
+) -> Callable[[Callable[P, R]], Callable[P, R]]:
+    """Decorator which emitts a DeprecationWarning if any arguments specified
+    are None or not passed at all.
+
+    Arguments should be a key-value mapping, with the key being the argument to check
+    and the value being a type annotation as string for the value of the argument.
+    """
+    # Helpful links
+    # Decorator for DeprecationWarning: https://stackoverflow.com/a/49802489
+    # Typing of stacked decorators: https://stackoverflow.com/a/68290080
+
+    def deco(func: Callable[P, R]) -> Callable[P, R]:
+        """Decorator function."""
+
+        @functools.wraps(func)
+        def wrapper(*args: P.args, **kwargs: P.kwargs) -> R:
+            """Emit DeprecationWarnings if conditions are met."""
+
+            keys = list(inspect.signature(func).parameters.keys())
+            for arg, type_annotation in arguments.items():
+                try:
+                    index = keys.index(arg)
+                except ValueError:
+                    raise Exception(
+                        f"Can't find argument '{arg}' for '{args[0].__class__.__qualname__}'"
+                    ) from None
+                if (
+                    # Check kwargs
+                    # - if found, check it's not None
+                    (arg in kwargs and kwargs[arg] is None)
+                    # Check args
+                    # - make sure not in kwargs
+                    # - len(args) needs to be long enough, if too short
+                    #   arg can't be in args either
+                    # - args[index] should not be None
+                    or arg not in kwargs
+                    and (
+                        index == -1
+                        or len(args) <= index
+                        or (len(args) > index and args[index] is None)
+                    )
+                ):
+                    warnings.warn(
+                        f"'{arg}' will be a required attribute for "
+                        f"'{args[0].__class__.__qualname__}.{func.__name__}' in astroid {astroid_version} "
+                        f"('{arg}' should be of type: '{type_annotation}')",
+                        DeprecationWarning,
+                    )
+            return func(*args, **kwargs)
+
+        return wrapper
+
+    return deco
