@@ -10,6 +10,7 @@
 # Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Peter Kolbus <peter.kolbus@gmail.com>
 # Copyright (c) 2020 Raphael Gaschignard <raphael@rtpg.co>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 DudeNr33 <3929834+DudeNr33@users.noreply.github.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
@@ -129,7 +130,7 @@ class ImportlibFinder(Finder):
 
         for entry in submodule_path:
             package_directory = os.path.join(entry, modname)
-            for suffix in [".py", importlib.machinery.BYTECODE_SUFFIXES[0]]:
+            for suffix in (".py", importlib.machinery.BYTECODE_SUFFIXES[0]):
                 package_file_name = "__init__" + suffix
                 file_path = os.path.join(package_directory, package_file_name)
                 if os.path.isfile(file_path):
@@ -223,7 +224,7 @@ class PathSpecFinder(Finder):
             # origin can be either a string on older Python versions
             # or None in case it is a namespace package:
             # https://github.com/python/cpython/pull/5481
-            is_namespace_pkg = spec.origin in ("namespace", None)
+            is_namespace_pkg = spec.origin in {"namespace", None}
             location = spec.origin if not is_namespace_pkg else None
             module_type = ModuleType.PY_NAMESPACE if is_namespace_pkg else None
             spec = ModuleSpec(
@@ -291,7 +292,6 @@ def _precache_zipimporters(path=None):
     req_paths = tuple(path or sys.path)
     cached_paths = tuple(pic)
     new_paths = _cached_set_diff(req_paths, cached_paths)
-    # pylint: disable=no-member
     for entry_path in new_paths:
         try:
             pic[entry_path] = zipimport.zipimporter(entry_path)
@@ -320,7 +320,7 @@ def _search_zip(modpath, pic):
                     os.path.abspath(filepath) + os.path.sep + os.path.sep.join(modpath),
                     filepath,
                 )
-    raise ImportError("No module named %s" % ".".join(modpath))
+    raise ImportError(f"No module named {'.'.join(modpath)}")
 
 
 def _find_spec_with_path(search_path, modname, module_parts, processed, submodule_path):
@@ -331,7 +331,7 @@ def _find_spec_with_path(search_path, modname, module_parts, processed, submodul
             continue
         return finder, spec
 
-    raise ImportError("No module named %s" % ".".join(module_parts))
+    raise ImportError(f"No module named {'.'.join(module_parts)}")
 
 
 def find_spec(modpath, path=None):
