@@ -7,6 +7,7 @@
 # Copyright (c) 2017 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2017 rr- <rr-@sakuya.pl>
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
@@ -113,6 +114,7 @@ from astroid.nodes.scoped_nodes import (
     GeneratorExp,
     Lambda,
     ListComp,
+    LocalsDictNodeNG,
     Module,
     SetComp,
     builtin_lookup,
@@ -176,6 +178,7 @@ ALL_NODE_CLASSES = (
     Lambda,
     List,
     ListComp,
+    LocalsDictNodeNG,
     Match,
     MatchAs,
     MatchCase,
@@ -268,6 +271,7 @@ __all__ = (
     "Lambda",
     "List",
     "ListComp",
+    "LocalsDictNodeNG",
     "Match",
     "MatchAs",
     "MatchCase",
