@@ -13,6 +13,7 @@
 # Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
 # Copyright (c) 2019 Alex Hall <alex.mojaki@gmail.com>
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 pre-commit-ci[bot] <bot@noreply.github.com>
@@ -69,7 +70,7 @@ class AsStringVisitor:
     def _precedence_parens(self, node, child, is_left=True):
         """Wrap child in parens only if required to keep same semantics"""
         if self._should_wrap(node, child, is_left):
-            return "(%s)" % child.accept(self)
+            return f"({child.accept(self)})"
 
         return child.accept(self)
 
@@ -98,13 +99,13 @@ class AsStringVisitor:
     # visit_<node> methods ###########################################
 
     def visit_await(self, node):
-        return "await %s" % node.value.accept(self)
+        return f"await {node.value.accept(self)}"
 
     def visit_asyncwith(self, node):
-        return "async %s" % self.visit_with(node)
+        return f"async {self.visit_with(node)}"
 
     def visit_asyncfor(self, node):
-        return "async %s" % self.visit_for(node)
+        return f"async {self.visit_for(node)}"
 
     def visit_arguments(self, node):
         """return an astroid.Function node as string"""
@@ -117,10 +118,8 @@ class AsStringVisitor:
     def visit_assert(self, node):
         """return an astroid.Assert node as string"""
         if node.fail:
-            return "assert {}, {}".format(
-                node.test.accept(self), node.fail.accept(self)
-            )
-        return "assert %s" % node.test.accept(self)
+            return f"assert {node.test.accept(self)}, {node.fail.accept(self)}"
+        return f"assert {node.test.accept(self)}"
 
     def visit_assignname(self, node):
         """return an astroid.AssName node as string"""
@@ -133,9 +132,7 @@ class AsStringVisitor:
 
     def visit_augassign(self, node):
         """return an astroid.AugAssign node as string"""
-        return "{} {} {}".format(
-            node.target.accept(self), node.op, node.value.accept(self)
-        )
+        return f"{node.target.accept(self)} {node.op} {node.value.accept(self)}"
 
     def visit_annassign(self, node):
         """Return an astroid.AugAssign node as string"""
@@ -157,8 +154,8 @@ class AsStringVisitor:
 
     def visit_boolop(self, node):
         """return an astroid.BoolOp node as string"""
-        values = ["%s" % self._precedence_parens(node, n) for n in node.values]
-        return (" %s " % node.op).join(values)
+        values = [f"{self._precedence_parens(node, n)}" for n in node.values]
+        return (f" {node.op} ").join(values)
 
     def visit_break(self, node):
         """return an astroid.Break node as string"""
@@ -174,7 +171,7 @@ class AsStringVisitor:
             keywords = []
 
         args.extend(keywords)
-        return "{}({})".format(expr_str, ", ".join(args))
+        return f"{expr_str}({', '.join(args)})"
 
     def visit_classdef(self, node):
         """return an astroid.ClassDef node as string"""
@@ -183,7 +180,7 @@ class AsStringVisitor:
         if node._metaclass and not node.has_metaclass_hack():
             args.append("metaclass=" + node._metaclass.accept(self))
         args += [n.accept(self) for n in node.keywords]
-        args = "(%s)" % ", ".join(args) if args else ""
+        args = f"({', '.join(args)})" if args else ""
         docs = self._docs_dedent(node.doc) if node.doc else ""
         return "\n\n{}class {}{}:{}\n{}\n".format(
             decorate, node.name, args, docs, self._stmt_list(node.body)
@@ -199,11 +196,9 @@ class AsStringVisitor:
 
     def visit_comprehension(self, node):
         """return an astroid.Comprehension node as string"""
-        ifs = "".join(" if %s" % n.accept(self) for n in node.ifs)
-        generated = "for {} in {}{}".format(
-            node.target.accept(self), node.iter.accept(self), ifs
-        )
-        return "{}{}".format("async " if node.is_async else "", generated)
+        ifs = "".join(f" if {n.accept(self)}" for n in node.ifs)
+        generated = f"for {node.target.accept(self)} in {node.iter.accept(self)}{ifs}"
+        return f"{'async ' if node.is_async else ''}{generated}"
 
     def visit_const(self, node):
         """return an astroid.Const node as string"""
@@ -217,7 +212,7 @@ class AsStringVisitor:
 
     def visit_delete(self, node):  # XXX check if correct
         """return an astroid.Delete node as string"""
-        return "del %s" % ", ".join(child.accept(self) for child in node.targets)
+        return f"del {', '.join(child.accept(self) for child in node.targets)}"
 
     def visit_delattr(self, node):
         """return an astroid.DelAttr node as string"""
@@ -267,11 +262,9 @@ class AsStringVisitor:
     def visit_excepthandler(self, node):
         if node.type:
             if node.name:
-                excs = "except {} as {}".format(
-                    node.type.accept(self), node.name.accept(self)
-                )
+                excs = f"except {node.type.accept(self)} as {node.name.accept(self)}"
             else:
-                excs = "except %s" % node.type.accept(self)
+                excs = f"except {node.type.accept(self)}"
         else:
             excs = "except"
         return f"{excs}:\n{self._stmt_list(node.body)}"
@@ -367,20 +360,20 @@ class AsStringVisitor:
         """return an astroid.Getattr node as string"""
         left = self._precedence_parens(node, node.expr)
         if left.isdigit():
-            left = "(%s)" % left
+            left = f"({left})"
         return f"{left}.{node.attrname}"
 
     def visit_global(self, node):
         """return an astroid.Global node as string"""
-        return "global %s" % ", ".join(node.names)
+        return f"global {', '.join(node.names)}"
 
     def visit_if(self, node):
         """return an astroid.If node as string"""
         ifs = [f"if {node.test.accept(self)}:\n{self._stmt_list(node.body)}"]
         if node.has_elif_block():
-            ifs.append("el%s" % self._stmt_list(node.orelse, indent=False))
+            ifs.append(f"el{self._stmt_list(node.orelse, indent=False)}")
         elif node.orelse:
-            ifs.append("else:\n%s" % self._stmt_list(node.orelse))
+            ifs.append(f"else:\n{self._stmt_list(node.orelse)}")
         return "\n".join(ifs)
 
     def visit_ifexp(self, node):
@@ -393,12 +386,12 @@ class AsStringVisitor:
 
     def visit_import(self, node):
         """return an astroid.Import node as string"""
-        return "import %s" % _import_string(node.names)
+        return f"import {_import_string(node.names)}"
 
     def visit_keyword(self, node):
         """return an astroid.Keyword node as string"""
         if node.arg is None:
-            return "**%s" % node.value.accept(self)
+            return f"**{node.value.accept(self)}"
         return f"{node.arg}={node.value.accept(self)}"
 
     def visit_lambda(self, node):
@@ -408,11 +401,11 @@ class AsStringVisitor:
         if args:
             return f"lambda {args}: {body}"
 
-        return "lambda: %s" % body
+        return f"lambda: {body}"
 
     def visit_list(self, node):
         """return an astroid.List node as string"""
-        return "[%s]" % ", ".join(child.accept(self) for child in node.elts)
+        return f"[{', '.join(child.accept(self) for child in node.elts)}]"
 
     def visit_listcomp(self, node):
         """return an astroid.ListComp node as string"""
@@ -422,7 +415,7 @@ class AsStringVisitor:
 
     def visit_module(self, node):
         """return an astroid.Module node as string"""
-        docs = '"""%s"""\n\n' % node.doc if node.doc else ""
+        docs = f'"""{node.doc}"""\n\n' if node.doc else ""
         return docs + "\n".join(n.accept(self) for n in node.body) + "\n\n"
 
     def visit_name(self, node):
@@ -437,7 +430,7 @@ class AsStringVisitor:
 
     def visit_nonlocal(self, node):
         """return an astroid.Nonlocal node as string"""
-        return "nonlocal %s" % ", ".join(node.names)
+        return f"nonlocal {', '.join(node.names)}"
 
     def visit_pass(self, node):
         """return an astroid.Pass node as string"""
@@ -447,20 +440,18 @@ class AsStringVisitor:
         """return an astroid.Raise node as string"""
         if node.exc:
             if node.cause:
-                return "raise {} from {}".format(
-                    node.exc.accept(self), node.cause.accept(self)
-                )
-            return "raise %s" % node.exc.accept(self)
+                return f"raise {node.exc.accept(self)} from {node.cause.accept(self)}"
+            return f"raise {node.exc.accept(self)}"
         return "raise"
 
     def visit_return(self, node):
         """return an astroid.Return node as string"""
         if node.is_tuple_return() and len(node.value.elts) > 1:
             elts = [child.accept(self) for child in node.value.elts]
-            return "return %s" % ", ".join(elts)
+            return f"return {', '.join(elts)}"
 
         if node.value:
-            return "return %s" % node.value.accept(self)
+            return f"return {node.value.accept(self)}"
 
         return "return"
 
@@ -497,11 +488,11 @@ class AsStringVisitor:
 
     def visit_tryexcept(self, node):
         """return an astroid.TryExcept node as string"""
-        trys = ["try:\n%s" % self._stmt_list(node.body)]
+        trys = [f"try:\n{self._stmt_list(node.body)}"]
         for handler in node.handlers:
             trys.append(handler.accept(self))
         if node.orelse:
-            trys.append("else:\n%s" % self._stmt_list(node.orelse))
+            trys.append(f"else:\n{self._stmt_list(node.orelse)}")
         return "\n".join(trys)
 
     def visit_tryfinally(self, node):
@@ -513,8 +504,8 @@ class AsStringVisitor:
     def visit_tuple(self, node):
         """return an astroid.Tuple node as string"""
         if len(node.elts) == 1:
-            return "(%s, )" % node.elts[0].accept(self)
-        return "(%s)" % ", ".join(child.accept(self) for child in node.elts)
+            return f"({node.elts[0].accept(self)}, )"
+        return f"({', '.join(child.accept(self) for child in node.elts)})"
 
     def visit_unaryop(self, node):
         """return an astroid.UnaryOp node as string"""
@@ -526,9 +517,7 @@ class AsStringVisitor:
 
     def visit_while(self, node):
         """return an astroid.While node as string"""
-        whiles = "while {}:\n{}".format(
-            node.test.accept(self), self._stmt_list(node.body)
-        )
+        whiles = f"while {node.test.accept(self)}:\n{self._stmt_list(node.body)}"
         if node.orelse:
             whiles = f"{whiles}\nelse:\n{self._stmt_list(node.orelse)}"
         return whiles
@@ -536,7 +525,7 @@ class AsStringVisitor:
     def visit_with(self, node):  # 'with' without 'as' is possible
         """return an astroid.With node as string"""
         items = ", ".join(
-            ("%s" % expr.accept(self)) + (v and " as %s" % (v.accept(self)) or "")
+            f"{expr.accept(self)}" + (v and f" as {v.accept(self)}" or "")
             for expr, v in node.items
         )
         return f"with {items}:\n{self._stmt_list(node.body)}"
