@@ -1,14 +1,32 @@
 import pprint
 import typing
 from functools import singledispatch as _singledispatch
-from typing import ClassVar, Iterator, Optional, Tuple, Type, TypeVar, Union, overload
+from typing import (
+    TYPE_CHECKING,
+    ClassVar,
+    Iterator,
+    Optional,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+    overload,
+)
 
 from astroid import decorators, util
-from astroid.exceptions import AstroidError, InferenceError, UseInferenceDefault
+from astroid.exceptions import (
+    AstroidError,
+    InferenceError,
+    ParentMissingError,
+    UseInferenceDefault,
+)
 from astroid.manager import AstroidManager
 from astroid.nodes.as_string import AsStringVisitor
 from astroid.nodes.const import OP_PRECEDENCE
 
+if TYPE_CHECKING:
+    from astroid.nodes import LocalsDictNodeNG
+
 # Types for 'NodeNG.nodes_of_class()'
 T_Nodes = TypeVar("T_Nodes", bound="NodeNG")
 T_Nodes2 = TypeVar("T_Nodes2", bound="NodeNG")
@@ -159,7 +177,7 @@ class NodeNG:
             inner = [lines[0]]
             for line in lines[1:]:
                 inner.append(" " * alignment + line)
-            result.append("{}={}".format(field, "".join(inner)))
+            result.append(f"{field}={''.join(inner)}")
 
         return string % {
             "cname": cname,
@@ -251,15 +269,15 @@ class NodeNG:
         """
         return self.parent.frame()
 
-    def scope(self):
+    def scope(self) -> "LocalsDictNodeNG":
         """The first parent node defining a new scope.
+        These can be Module, FunctionDef, ClassDef, Lambda, or GeneratorExp nodes.
 
         :returns: The first parent scope node.
-        :rtype: Module or FunctionDef or ClassDef or Lambda or GenExpr
         """
-        if self.parent:
-            return self.parent.scope()
-        return None
+        if not self.parent:
+            raise ParentMissingError(target=self)
+        return self.parent.scope()
 
     def root(self):
         """Return the root node of the syntax tree.
@@ -633,10 +651,7 @@ class NodeNG:
             """Outputs a strings representation of an astroid node."""
             if node in done:
                 result.append(
-                    indent
-                    + "<Recursion on {} with id={}".format(
-                        type(node).__name__, id(node)
-                    )
+                    indent + f"<Recursion on {type(node).__name__} with id={id(node)}"
                 )
                 return False
             done.add(node)
@@ -649,7 +664,7 @@ class NodeNG:
             if ids:
                 result.append(f"{type(node).__name__}<0x{id(node):x}>(\n")
             else:
-                result.append("%s(" % type(node).__name__)
+                result.append(f"{type(node).__name__}(")
             fields = []
             if include_linenos:
                 fields.extend(("lineno", "col_offset"))
@@ -660,7 +675,7 @@ class NodeNG:
             if not fields:
                 broken = False
             elif len(fields) == 1:
-                result.append("%s=" % fields[0])
+                result.append(f"{fields[0]}=")
                 broken = _repr_tree(
                     getattr(node, fields[0]), result, done, cur_indent, depth
                 )
@@ -668,11 +683,11 @@ class NodeNG:
                 result.append("\n")
                 result.append(cur_indent)
                 for field in fields[:-1]:
-                    result.append("%s=" % field)
+                    result.append(f"{field}=")
                     _repr_tree(getattr(node, field), result, done, cur_indent, depth)
                     result.append(",\n")
                     result.append(cur_indent)
-                result.append("%s=" % fields[-1])
+                result.append(f"{fields[-1]}=")
                 _repr_tree(getattr(node, fields[-1]), result, done, cur_indent, depth)
                 broken = True
             result.append(")")
